@@ -1,12 +1,12 @@
-import src.jadecobra.aws_lambda
-import src.jadecobra.toolkit
+import jadecobra.aws_lambda
+import jadecobra.toolkit
 
 
-class TestAwsLambda(src.jadecobra.toolkit.TestCase):
+class TestAwsLambda(jadecobra.toolkit.TestCase):
 
     def test_aws_lambda(self):
         self.assert_attributes_equal(
-            src.jadecobra.aws_lambda,
+            jadecobra.aws_lambda,
             [
                 '__builtins__',
                 '__cached__',
@@ -27,7 +27,7 @@ class TestAwsLambda(src.jadecobra.toolkit.TestCase):
         account = "012345678901"
         name = "lambda_function_name"
         self.assertEqual(
-            src.jadecobra.aws_lambda.get_arn(
+            jadecobra.aws_lambda.get_arn(
                 region=region,
                 account=account,
                 name=name
